@@ -49,8 +49,7 @@ class RawSearchSharePointField(serializers.ReadOnlyField):
     Gets the name of the field without any transformation
     """
     def get_attribute(self, instance):
-        items = [item['Value'] for item in instance if item['Key'] == self.source]
-        return items[0] if items else 'N/A'
+        return instance.get(self.source, 'N/A')
 
 
 class SearchSharePointField(serializers.ReadOnlyField):
@@ -60,8 +59,7 @@ class SearchSharePointField(serializers.ReadOnlyField):
     """
     def get_attribute(self, instance):
         field_name = to_camel(self.source)
-        items = [item['Value'] for item in instance if item['Key'] == field_name]
-        return items[0] if items else 'N/A'
+        return instance.get(field_name, 'N/A')
 
 
 class CapitalizeSearchSharePointField(serializers.ReadOnlyField):
@@ -71,5 +69,4 @@ class CapitalizeSearchSharePointField(serializers.ReadOnlyField):
     """
     def get_attribute(self, instance):
         field_name = first_upper(self.source)
-        items = [item['Value'] for item in instance if item['Key'] == field_name]
-        return items[0] if items else 'N/A'
+        return instance.get(field_name, 'N/A')
